==> 0.0.13.tar.gz: android/src/main/kotlin/com/example/spectus_paykun/SpectusPaykunPlugin.kt <==
package com.example.spectus_paykun

import androidx.annotation.NonNull

import android.app.Activity
import android.content.Context
import android.util.Log
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** SpectusPaykunPlugin */
class SpectusPaykunPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var mActivity : Activity? = null
  var mContext : Context? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "spectus_paykun")
    channel.setMethodCallHandler(this)
    mContext = flutterPluginBinding.applicationContext
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        Log.e("onAttachedToActivity","Called")
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
        TODO("Not yet implemented")
    }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } 
    else if (call.method == "startPayKunPayment") {

      var merchantId = call.argument<String>("merchantId")!!
      var accessToken = call.argument<String>("accessToken")!!
      var customerName = call.argument<String>("customerName")!!
      var customerEmail = call.argument<String>("customerEmail")!!
      var customerPhone = call.argument<String>("customerPhone")!!
      var productName = call.argument<String>("productName")!!
      var amount = call.argument<String>("amount")!!
      var currency = call.argument<String>("currency")!!
      var isLive = call.argument<Boolean>("isLive")!!

      if(mActivity==null){
            Log.e("Mactivity","Null")
        }

      PayKunPayment.startPayKunPayment(activityObj: mActivity, merchantId: merchantId, accessToken: accessToken,
                                      customerName: customerName, customerEmail:customerEmail,
                                      customerPhone: customerPhone, productName: productName,
                                      currency: currency, amount: amount, isLive: isLive,
                                      { error, transactionID, prodcutDetails ->
                                        Log.e("Callback in Dart","")
                                        if (error != null) {
                                            Log.e("Inside Error Log","")
                                            mActivity!!.runOnUiThread(Runnable {
                                                //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                                result.error("1", "Array Empty", "NoDetails")
                                            })
                                        } else {
                                          Log.e("Operation Not Null","" + operationResult!!.toString())
                                          mActivity!!.runOnUiThread(Runnable {
                                              //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                              result.success(transactionID)
                                          })
                                        }
                                    })
    }
    else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> 0.0.20.tar.gz: android/src/main/kotlin/com/example/spectus_paykun/SpectusPaykunPlugin.kt <==
package com.example.spectus_paykun

import androidx.annotation.NonNull

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Build
import android.util.Log
import com.app.ready.paykundemo.PayKunPayment
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry

/** SpectusPaykunPlugin */
class SpectusPaykunPlugin: FlutterPlugin, ActivityAware, MethodCallHandler, PluginRegistry.ActivityResultListener {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var mActivity : Activity? = null
  var mContext : Context? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "spectus_paykun")
    channel.setMethodCallHandler(this)
    mContext = flutterPluginBinding.applicationContext
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        Log.e("onAttachedToActivity","Called")
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity
    }

    override fun onDetachedFromActivity() {
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${Build.VERSION.RELEASE}")
    } 
    else if (call.method == "startPayKunPayment") {

      var merchantId = call.argument<String>("merchantId")!!
      var accessToken = call.argument<String>("accessToken")!!
      var customerName = call.argument<String>("customerName")!!
      var customerEmail = call.argument<String>("customerEmail")!!
      var customerPhone = call.argument<String>("customerPhone")!!
      var productName = call.argument<String>("productName")!!
      var amount = call.argument<String>("amount")!!
      var currency = call.argument<String>("currency")!!
      var isLive = call.argument<Boolean>("isLive")!!

      if(mActivity==null){
            Log.e("Mactivity","Null")
        }

      PayKunPayment().startPayKunPayment( mActivity!!, merchantId, accessToken,
                                      customerName, customerEmail,
                                      customerPhone, productName,
                                      currency, amount, isLive,
                                      { error, transactionID, prodcutDetails ->
                                        Log.e("Callback in Dart","")
                                        if (error != null) {
                                            Log.e("Inside Error Log","")
                                            mActivity!!.runOnUiThread(Runnable {
                                                //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                                result.error("1", "Array Empty", "NoDetails")
                                            })
                                        } else {
                                          mActivity!!.runOnUiThread(Runnable {
                                              //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                              result.success(transactionID)
                                          })
                                        }
                                    })
    }
    else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        return false
    }
}
